@@ -38,4 +38,4 @@ class NewCommandTimeoutOption(SupportsCapabilities):
         Set the allowed time before seeing a new server command.
         The value could either be provided as timedelta instance or an integer number of seconds.
         """
-        self.set_capability(NEW_COMMAND_TIMEOUT, value.seconds if isinstance(value, timedelta) else value)
+        self.set_capability(NEW_COMMAND_TIMEOUT, value.total_seconds() if isinstance(value, timedelta) else value)
